Рейтинг композиций
Пред. | Глава 1. Архитектура | След.

## Рейтинг композиций

У каждой композиции есть два рейтинга: реальный, зависящий от количества проголосовавших пользователей, и оперативный, используемый в ротации.

Реальный рейтинг композиции по умолчанию равен 1.0 и изменяется на 0.25 с каждым голосом слушателя (засчитывается только последний голос, так что каждый слушатель может изменить реальный рейтинг композиции только на +0.25 или -0.25). Голос пользователя при этом умножается на его вес, который рассчитывается по формуле (T-X)/T, где T=30, а X — количество дней с последнего голосования за любую композицию. Если слушатель перестаёт голосовать, сила его голоса плавно затухает, а по истечение 30 дней его голос вообще перестаёт что-либо значить. Однако как только пользователь снова проголосует, его прежние голоса снова начнут влиять не реальный рейтинг композиций.

Оперативный рейтинг изначально равен реальному, но изменяется на 0.25 при каждом голосовании после того, как песня прозвучала вновь (т.е. один раз за проигрывание песни). При повторном голосовании рейтинг изменяется снова, что даёт целеустремлённому слушателю возможность вывести композицию в самый топ или загнать её в самый низ (но не ниже 0.25). Этот рейтинг непосредственно влияет на вероятность попадания песни в плейлист. Однако при каждом проигрывании песни рейтинг на 0.1 приближается к реальному значению, то есть медленно восстанавливается.

Для голосования за песни используется jabber-бот и команды rocks и sucks.

Пред. | Наверх | След.
Глава 1. Архитектура | Начало | Глава 2. Установка